//! # Independent push notification service
//!
//! @author Pierre Hubert


use actix_web::http::HeaderValue;
use reqwest::blocking::Client;
use reqwest::header::HeaderMap;
use serde::Deserialize;

use crate::data::config::{conf, IndependentPushService};
use crate::data::error::{ExecError, Res};

#[derive(Deserialize)]
struct CreateTokenResult {
    token: String
}

fn svc_conf() -> Res<&'static IndependentPushService> {
    match &conf().independent_push_service {
        Some(c) => Ok(c),
        None => Err(ExecError::boxed_new("Missing push configuration!")),
    }
}

fn create_client() -> Res<Client> {
    let mut headers = HeaderMap::new();
    headers.insert("token", HeaderValue::from_str(&svc_conf()?.control_token.clone())?);
    Ok(Client::builder().default_headers(headers).build()?)
}

/// Create a new client token
pub fn create_token() -> Res<String> {
    let client = create_client()?
        .get(&format!("{}{}", svc_conf()?.control_url, "create_client"))
        .send()?;


    let response: CreateTokenResult = client.json()?;

    Ok(response.token)
}